@@ -3,9 +3,9 @@ Main interface for robomaker service type definitions.
 
 Usage::
 
-    from mypy_boto3.robomaker.type_defs import S3KeyOutputTypeDef
+    from mypy_boto3.robomaker.type_defs import ComputeResponseTypeDef
 
-    data: S3KeyOutputTypeDef = {...}
+    data: ComputeResponseTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,6 +22,7 @@ else:
 
 
 __all__ = (
+    "ComputeResponseTypeDef",
     "S3KeyOutputTypeDef",
     "DataSourceTypeDef",
     "LoggingConfigTypeDef",
@@ -36,6 +37,7 @@ __all__ = (
     "SimulationJobTypeDef",
     "BatchDescribeSimulationJobResponseTypeDef",
     "BatchPolicyTypeDef",
+    "ComputeTypeDef",
     "DeploymentLaunchConfigTypeDef",
     "DeploymentApplicationConfigTypeDef",
     "S3ObjectTypeDef",
@@ -91,6 +93,10 @@ __all__ = (
     "UpdateSimulationApplicationResponseTypeDef",
 )
 
+ComputeResponseTypeDef = TypedDict(
+    "ComputeResponseTypeDef", {"simulationUnitLimit": int}, total=False
+)
+
 S3KeyOutputTypeDef = TypedDict("S3KeyOutputTypeDef", {"s3Key": str, "etag": str}, total=False)
 
 DataSourceTypeDef = TypedDict(
@@ -243,6 +249,7 @@ SimulationJobTypeDef = TypedDict(
         "tags": Dict[str, str],
         "vpcConfig": VPCConfigResponseTypeDef,
         "networkInterface": NetworkInterfaceTypeDef,
+        "compute": ComputeResponseTypeDef,
     },
     total=False,
 )
@@ -257,6 +264,8 @@ BatchPolicyTypeDef = TypedDict(
     "BatchPolicyTypeDef", {"timeoutInSeconds": int, "maxConcurrency": int}, total=False
 )
 
+ComputeTypeDef = TypedDict("ComputeTypeDef", {"simulationUnitLimit": int}, total=False)
+
 _RequiredDeploymentLaunchConfigTypeDef = TypedDict(
     "_RequiredDeploymentLaunchConfigTypeDef", {"packageName": str, "launchFile": str}
 )
@@ -501,6 +510,7 @@ CreateSimulationJobResponseTypeDef = TypedDict(
         "dataSources": List[DataSourceTypeDef],
         "tags": Dict[str, str],
         "vpcConfig": VPCConfigResponseTypeDef,
+        "compute": ComputeResponseTypeDef,
     },
     total=False,
 )
@@ -736,6 +746,7 @@ _OptionalSimulationJobRequestTypeDef = TypedDict(
         "simulationApplications": List[SimulationApplicationConfigTypeDef],
         "dataSources": List[DataSourceConfigTypeDef],
         "vpcConfig": VPCConfigTypeDef,
+        "compute": ComputeTypeDef,
         "tags": Dict[str, str],
     },
     total=False,
@@ -903,6 +914,7 @@ DescribeSimulationJobResponseTypeDef = TypedDict(
         "tags": Dict[str, str],
         "vpcConfig": VPCConfigResponseTypeDef,
         "networkInterface": NetworkInterfaceTypeDef,
+        "compute": ComputeResponseTypeDef,
     },
     total=False,
 )
